@@ -32,6 +32,10 @@ xx(dumpconfig,
    "Dump active configuration",
    "dumpconfig <filename>\n")
 
+xx(formats,
+   "List available metadata formats",
+   "formats\n")
+
 xx(help,
    "Display help for commands",
    "help <command>" "\n")
@@ -50,9 +54,9 @@ xx(lvchange,
    "Change the attributes of logical volume(s)",
    "lvchange\n"
    "\t[-A|--autobackup y|n]\n"
-   "\t[-a|--available y|n]\n"
+   "\t[-a|--available [e|l]y|n]\n"
    "\t[--addtag Tag]\n"
-   "\t[--alloc AllocationType]\n"
+   "\t[--alloc AllocationPolicy]\n"
    "\t[-C|--contiguous y|n]\n"
    "\t[-d|--debug]\n"
    "\t[--deltag Tag]\n"
@@ -79,7 +83,7 @@ xx(lvcreate,
    "lvcreate " "\n"
    "\t[-A|--autobackup {y|n}]\n"
    "\t[--addtag Tag]\n"
-   "\t[--alloc AllocationType]\n"
+   "\t[--alloc AllocationPolicy]\n"
    "\t[-C|--contiguous {y|n}]\n"
    "\t[-d|--debug]\n"
    "\t[-h|-?|--help]\n"
@@ -101,7 +105,7 @@ xx(lvcreate,
    "\t[-c|--chunksize]\n"
    "\t[-A|--autobackup {y|n}]\n"
    "\t[--addtag Tag]\n"
-   "\t[--alloc AllocationType]\n"
+   "\t[--alloc AllocationPolicy]\n"
    "\t[-C|--contiguous {y|n}]\n"
    "\t[-d|--debug]\n"
    "\t[-h|-?|--help]\n"
@@ -163,7 +167,7 @@ xx(lvextend,
    "Add space to a logical volume",
    "lvextend\n"
    "\t[-A|--autobackup y|n]\n"
-   "\t[--alloc AllocationType]\n"
+   "\t[--alloc AllocationPolicy]\n"
    "\t[-d|--debug]\n"
    "\t[-h|--help]\n"
    "\t[-i|--stripes Stripes [-I|--stripesize StripeSize]]\n"
@@ -274,7 +278,7 @@ xx(lvresize,
    "Resize a logical volume",
    "lvresize\n"
    "\t[-A|--autobackup y|n]\n"
-   "\t[--alloc AllocationType]\n"
+   "\t[--alloc AllocationPolicy]\n"
    "\t[-d|--debug]\n"
    "\t[-h|--help]\n"
    "\t[-i|--stripes Stripes [-I|--stripesize StripeSize]]\n"
@@ -363,12 +367,13 @@ xx(pvcreate,
    "\t[-u|--uuid uuid] " "\n"
    "\t[-v|--verbose] " "\n"
    "\t[-y|--yes]" "\n"
+   "\t[-Z|--zero {y|n}]\n"
    "\t[--version] " "\n"
    "\tPhysicalVolume [PhysicalVolume...]\n",
 
    force_ARG, test_ARG, labelsector_ARG, metadatatype_ARG, metadatacopies_ARG,
    metadatasize_ARG, physicalvolumesize_ARG, restorefile_ARG, uuidstr_ARG,
-   yes_ARG)
+   yes_ARG, zero_ARG)
 
 xx(pvdata,
    "Display the on-disk metadata for physical volume(s)",
@@ -428,9 +433,9 @@ xx(pvmove,
    "pvmove " "\n"
    "\t[--abort]\n"
    "\t[-A|--autobackup {y|n}]\n"
+   "\t[--alloc AllocationPolicy]\n"
    "\t[-b|--background]\n"
    "\t[-d|--debug]\n "
-   "\t[-f|--force]\n"
    "\t[-h|-?|--help]\n"
    "\t[-i|--interval seconds]\n"
    "\t[-t|--test]\n "
@@ -441,8 +446,8 @@ xx(pvmove,
    "\tSourcePhysicalVolume[:PhysicalExtent[-PhysicalExtent]...]}\n"
    "\t[DestinationPhysicalVolume[:PhysicalExtent[-PhysicalExtent]...]...]\n",
 
-   abort_ARG, autobackup_ARG, background_ARG, force_ARG, interval_ARG, name_ARG,
-   test_ARG)
+   abort_ARG, alloc_ARG, autobackup_ARG, background_ARG, 
+   interval_ARG, name_ARG, test_ARG)
 
 xx(pvremove,
    "Remove LVM label(s) from physical volume(s)",
@@ -512,6 +517,10 @@ xx(pvscan,
    exported_ARG, ignorelockingfailure_ARG, novolumegroup_ARG, partial_ARG,
    short_ARG, uuid_ARG)
 
+xx(segtypes,
+   "List available segment types",
+   "segtypes\n")
+
 xx(vgcfgbackup,
    "Backup volume group configuration(s)",
    "vgcfgbackup " "\n"
@@ -546,7 +555,7 @@ xx(vgchange,
    "Change volume group attributes",
    "vgchange" "\n"
    "\t[-A|--autobackup {y|n}] " "\n"
-   "\t[--alloc AllocationType] " "\n"
+   "\t[--alloc AllocationPolicy] " "\n"
    "\t[-P|--partial] " "\n"
    "\t[-d|--debug] " "\n"
    "\t[-h|--help] " "\n"
@@ -555,7 +564,7 @@ xx(vgchange,
    "\t[-u|--uuid] " "\n"
    "\t[-v|--verbose] " "\n"
    "\t[--version]" "\n"
-   "\t{-a|--available {y|n}  |" "\n"
+   "\t{-a|--available [e|l]{y|n}  |" "\n"
    "\t -x|--resizeable {y|n} |" "\n"
    "\t -l|--logicalvolume MaxLogicalVolumes |" "\n"
    "\t --addtag Tag |\n"
@@ -597,7 +606,7 @@ xx(vgcreate,
    "vgcreate" "\n"
    "\t[-A|--autobackup {y|n}] " "\n"
    "\t[--addtag Tag] " "\n"
-   "\t[--alloc AllocationType] " "\n"
+   "\t[--alloc AllocationPolicy] " "\n"
    "\t[-d|--debug]" "\n"
    "\t[-h|--help]" "\n"
    "\t[-l|--maxlogicalvolumes MaxLogicalVolumes]" "\n"
@@ -645,7 +654,7 @@ xx(vgdisplay,
 
    activevolumegroups_ARG, aligned_ARG, colon_ARG, columns_ARG, disk_ARG,
    ignorelockingfailure_ARG, noheadings_ARG, nosuffix_ARG, options_ARG,
-   partial_ARG, separator_ARG, short_ARG, sort_ARG, unbuffered_ARG, units_ARG)
+   partial_ARG, short_ARG, separator_ARG, sort_ARG, unbuffered_ARG, units_ARG)
 
 xx(vgexport,
    "Unregister volume group(s) from the system",
