@@ -26,6 +26,7 @@
 #include <libgen.h>
 #include <sys/stat.h>
 #include <time.h>
+#include <sys/resource.h>
 
 #ifdef HAVE_GETOPTLONG
 #  include <getopt.h>
@@ -89,7 +90,8 @@ int yes_no_excl_arg(struct cmd_context *cmd, struct arg *a)
 {
 	a->sign = SIGN_NONE;
 
-	if (!strcmp(a->value, "e")) {
+	if (!strcmp(a->value, "e") || !strcmp(a->value, "ey") ||
+	    !strcmp(a->value, "ye")) {
 		a->i_value = CHANGE_AE;
 		a->ui_value = CHANGE_AE;
 	}
@@ -99,7 +101,8 @@ int yes_no_excl_arg(struct cmd_context *cmd, struct arg *a)
 		a->ui_value = CHANGE_AY;
 	}
 
-	else if (!strcmp(a->value, "n")) {
+	else if (!strcmp(a->value, "n") || !strcmp(a->value, "en") ||
+		 !strcmp(a->value, "ne")) {
 		a->i_value = CHANGE_AN;
 		a->ui_value = CHANGE_AN;
 	}
@@ -805,7 +808,7 @@ static int _run_command(struct cmd_context *cmd, int argc, char **argv)
 	if (!(cmd->cmd_line = _copy_command_line(cmd, argc, argv)))
 		return ECMD_FAILED;
 
-	log_debug("Processing: %s", cmd->cmd_line);
+	log_debug("Parsing: %s", cmd->cmd_line);
 
 	if (!(cmd->command = _find_command(argv[0])))
 		return ENO_SUCH_CMD;
@@ -829,6 +832,12 @@ static int _run_command(struct cmd_context *cmd, int argc, char **argv)
 		goto out;
 	_apply_settings(cmd);
 
+	log_debug("Processing: %s", cmd->cmd_line);
+
+#ifdef O_DIRECT_SUPPORT
+	log_debug("O_DIRECT will be used");
+#endif
+
 	if ((ret = _process_common_commands(cmd)))
 		goto out;
 
@@ -965,6 +974,26 @@ static int _init_backup(struct cmd_context *cmd, struct config_tree *cft)
 	return 1;
 }
 
+static void _close_stray_fds(void)
+{
+	struct rlimit rlim;
+	int fd;
+
+	if (getrlimit(RLIMIT_NOFILE, &rlim) < 0) {
+		fprintf(stderr, "getrlimit(RLIMIT_NOFILE) failed: %s\n",
+			strerror(errno));
+		return;
+	}
+
+	for (fd = 3; fd < rlim.rlim_cur; fd++) {
+		if (!close(fd))
+			fprintf(stderr, "File descriptor %d left open\n", fd);
+		else if (errno != EBADF)
+			fprintf(stderr, "Close failed on stray file "
+				"descriptor %d: %s\n", fd, strerror(errno));
+	}
+}
+
 static struct cmd_context *_init_lvm(void)
 {
 	struct cmd_context *cmd;
@@ -1386,6 +1415,8 @@ int lvm2_main(int argc, char **argv)
 	int ret, alias = 0;
 	struct cmd_context *cmd;
 
+	_close_stray_fds();
+
 	if (!(cmd = _init_lvm()))
 		return -1;
 
